summaryrefslogtreecommitdiffstats
path: root/tdecore/kdesktopfile.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:35:07 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:35:07 -0600
commit703fb0c89c2eee56a1e613e67a446db9d4287929 (patch)
treedd8c5ca66075cd89c2638a2b48cf78386a9870a7 /tdecore/kdesktopfile.cpp
parent818e7abec3d5d3809b6b77293558678371c16b71 (diff)
downloadtdelibs-703fb0c89c2eee56a1e613e67a446db9d4287929.tar.gz
tdelibs-703fb0c89c2eee56a1e613e67a446db9d4287929.zip
Rename KCModule, KConfig, KIO, KServer, and KSocket to avoid conflicts with KDE4
Diffstat (limited to 'tdecore/kdesktopfile.cpp')
-rw-r--r--tdecore/kdesktopfile.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/tdecore/kdesktopfile.cpp b/tdecore/kdesktopfile.cpp
index 29c30f9d9..1b9a49890 100644
--- a/tdecore/kdesktopfile.cpp
+++ b/tdecore/kdesktopfile.cpp
@@ -42,9 +42,9 @@
KDesktopFile::KDesktopFile(const TQString &fileName, bool bReadOnly,
const char * resType)
- : KConfig(TQString::fromLatin1(""), bReadOnly, false)
+ : TDEConfig(TQString::fromLatin1(""), bReadOnly, false)
{
// KConfigBackEnd will try to locate the filename that is provided
// based on the resource type specified, _only_ if the filename
// is not an absolute path.
backEnd->changeFileName(fileName, resType, false);
@@ -346,7 +346,7 @@ KDesktopFile::sortOrder() const
}
void KDesktopFile::virtual_hook( int id, void* data )
-{ KConfig::virtual_hook( id, data ); }
+{ TDEConfig::virtual_hook( id, data ); }
TQString KDesktopFile::readDocPath() const
{
@@ -361,7 +361,7 @@ TQString KDesktopFile::readDocPath() const
KDesktopFile* KDesktopFile::copyTo(const TQString &file) const
{
KDesktopFile *config = new KDesktopFile(TQString::null, false);
- KConfig::copyTo(file, config);
+ TDEConfig::copyTo(file, config);
config->setDesktopGroup();
return config;
}
@@ -42,9 +42,9 @@
{
- // KConfigBackEnd will try to locate the filename that is provided
+ // TDEConfigBackEnd will try to locate the filename that is provided
// based on the resource type specified, _only_ if the filename
// is not an absolute path.